Crate graphify_watch

Crate graphify_watch 

File watching and auto-rebuild for graphify.

Uses notify + debouncing to watch for file changes and trigger incremental graph rebuilds. Port of Python watch.py.

Enums

WatchError
Errors from the watcher.

Functions

watch_directory
Watch root for file changes and trigger rebuilds into output_dir.